==> deepin-update-ui_1.0.12.tar.xz: BUILD/src/dde-update/translations/dde-update_pl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pl">
<context>
    <name>CheckProgressWidget</name>
    <message>
        <source>The check is almost complete, thank you for your patience</source>
        <translation>Skanowanie prawie zakończone, dziękujemy za cierpliwość</translation>
    </message>
    <message>
        <source>Preparing</source>
        <translation>Przygotowuję</translation>
    </message>
</context>
<context>
    <name>ErrorFrame</name>
    <message>
        <source>Checked for some errors</source>
        <translation>Przeskanowano w poszukiwaniu błędów</translation>
    </message>
</context>
<context>
    <name>SuccessFrame</name>
    <message>
        <source>Go to Desktop</source>
        <translation>Przejdź na pulpit</translation>
    </message>
    <message>
        <source>Welcome, system updated successfully</source>
        <translation>Witamy, system został zaktualizowany pomyślnie</translation>
    </message>
    <message>
        <source>Current Edition:</source>
        <translation>Obecne wydanie:</translation>
    </message>
</context>
<context>
    <name>UpdateCompleteWidget</name>
    <message>
        <source>View Logs</source>
        <translation>Wyświetl dzienniki</translation>
    </message>
    <message>
        <source>Updates successful</source>
        <translation>Zaktualizowano pomyślnie</translation>
    </message>
    <message>
        <source>Your computer will reboot soon %1</source>
        <translation>Komputer uruchomi się ponownie za %1</translation>
    </message>
    <message>
        <source>Your computer will be turned off soon %1</source>
        <translation>Komputer zostanie wyłączony za %1</translation>
    </message>
    <message>
        <source>The automatic reboot process has failed. Please try to manually reboot your device.</source>
        <translation>Nie udało się automatycznie uruchomić ponownie urządzenia. Uruchom ponownie ręcznie.</translation>
    </message>
    <message>
        <source>The automatic shutdown process has failed. Please try to manually shut down your device.</source>
        <translation>Nie udało się automatycznie uruchomić ponownie urządzenia. Uruchom ponownie ręcznie.</translation>
    </message>
</context>
<context>
    <name>UpdateLogWidget</name>
    <message>
        <source>Hide Logs</source>
        <translation>Ukryj dzienniki</translation>
    </message>
</context>
<context>
    <name>UpdateModel</name>
    <message>
        <source>Update failed</source>
        <translation>Błąd aktualizacji</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Nieznany błąd</translation>
    </message>
    <message>
        <source>Backup failed</source>
        <translation>Błąd tworzenia kopii zapasowej</translation>
    </message>
    <message>
        <source>Unable to perform system backup. If you continue the updates, you cannot roll back to the old system later.</source>
        <translation>Nie udało się utworzyć kopii zapasowej. Jeśli kontynuujesz aktualizacje, nie będziesz mógł przywrócić starego systemu.</translation>
    </message>
    <message>
        <source>Insufficient disk space. Please clean up your disk and try again.</source>
        <translation>Za mało miejsca na dysku. Uprzątnij go i spróbuj ponownie.</translation>
    </message>
    <message>
        <source>Failed to connect to backup services. Please check and retry again.</source>
        <translation>Nie udało się połączyć z usługami kopii zapasowej. Sprawdź problem i spróbuj ponownie.</translation>
    </message>
    <message>
        <source>Failed to connect to update services. Please check and retry again.</source>
        <translation>Nie udało się połączyć z usługami aktualizacji. Sprawdź problem i spróbuj ponownie.</translation>
    </message>
    <message>
        <source>Dependency error</source>
        <translation>Błąd zależności</translation>
    </message>
    <message>
        <source>DPKG error</source>
        <translation>Błąd DPKG</translation>
    </message>
    <message>
        <source>Back Up Again</source>
        <translation>Utwórz ponownie kopię zapasową</translation>
    </message>
    <message>
        <source>Abort</source>
        <translation>Przerwij</translation>
    </message>
    <message>
        <source>Proceed to Update</source>
        <translation>Przejdź do aktualizacji</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Uruchom ponownie</translation>
    </message>
    <message>
        <source>Shut Down</source>
        <translation>Zamknij</translation>
    </message>
    <message>
        <source>Go to Desktop</source>
        <translation>Przejdź na pulpit</translation>
    </message>
</context>
<context>
    <name>UpdatePrepareWidget</name>
    <message>
        <source>Preparing for updates…</source>
        <translation>Przygotowanie aktualizacji...</translation>
    </message>
</context>
<context>
    <name>UpdateProgressWidget</name>
    <message>
        <source>Do not force a shutdown or power off when installing updates. Otherwise, your system may be damaged.</source>
        <translation>Nie wymuszaj zamknięcia, ani nie odłączaj źródła zasilania podczas instalowania aktualizacji. W przeciwnym razie Twój system może ulec uszkodzeniu.</translation>
    </message>
</context>
</TS>

==> deepin-update-ui_1.0.31.tar.xz: BUILD/src/dde-update/translations/dde-update_pl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pl">
<context>
    <name>CheckProgressWidget</name>
    <message>
        <source>The check is almost complete, thank you for your patience</source>
        <translation>Skanowanie prawie zakończone, dziękujemy za cierpliwość</translation>
    </message>
    <message>
        <source>Preparing</source>
        <translation>Przygotowuję</translation>
    </message>
</context>
<context>
    <name>ErrorFrame</name>
    <message>
        <source>Checked for some errors</source>
        <translation>Przeskanowano w poszukiwaniu błędów</translation>
    </message>
</context>
<context>
    <name>SuccessFrame</name>
    <message>
        <source>Go to Desktop</source>
        <translation>Przejdź na pulpit</translation>
    </message>
    <message>
        <source>Welcome, system updated successfully</source>
        <translation>Witamy, system został zaktualizowany pomyślnie</translation>
    </message>
    <message>
        <source>Current Edition:</source>
        <translation>Obecne wydanie:</translation>
    </message>
</context>
<context>
    <name>UpdateCompleteWidget</name>
    <message>
        <source>Updates successful</source>
        <translation>Zaktualizowano pomyślnie</translation>
    </message>
    <message>
        <source>Your computer will reboot soon %1</source>
        <translation>Komputer uruchomi się ponownie za %1</translation>
    </message>
    <message>
        <source>Your computer will be turned off soon %1</source>
        <translation>Komputer zostanie wyłączony za %1</translation>
    </message>
    <message>
        <source>The automatic reboot process has failed. Please try to manually reboot your device.</source>
        <translation>Nie udało się automatycznie uruchomić ponownie urządzenia. Uruchom ponownie ręcznie.</translation>
    </message>
    <message>
        <source>The automatic shutdown process has failed. Please try to manually shut down your device.</source>
        <translation>Nie udało się automatycznie uruchomić ponownie urządzenia. Uruchom ponownie ręcznie.</translation>
    </message>
    <message>
        <source>View update logs</source>
        <translation>Pokaż dziennik aktualizacji</translation>
    </message>
    <message>
        <source>Collapse update logs</source>
        <translation>Zwiń dziennik aktualizacji</translation>
    </message>
</context>
<context>
    <name>UpdateLogWidget</name>
    <message>
        <source>Export</source>
        <translation>Eksportuj</translation>
    </message>
    <message>
        <source>The log has been exported to the desktop</source>
        <translation>Wysłano dzienniki na pulpit</translation>
    </message>
    <message>
        <source>Log export failed, please try again</source>
        <translation>Błąd eksportowania dzienników, spróbuj ponownie</translation>
    </message>
</context>
<context>
    <name>UpdateModel</name>
    <message>
        <source>Update failed</source>
        <translation>Błąd aktualizacji</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Nieznany błąd</translation>
    </message>
    <message>
        <source>Backup failed</source>
        <translation>Błąd tworzenia kopii zapasowej</translation>
    </message>
    <message>
        <source>Unable to perform system backup. If you continue the updates, you cannot roll back to the old system later.</source>
        <translation>Nie udało się utworzyć kopii zapasowej. Kontynuując, nie będzie można przywrócić starego systemu.</translation>
    </message>
    <message>
        <source>Insufficient disk space. Please clean up your disk and try again.</source>
        <translation>Za mało miejsca na dysku. Uprzątnij go i spróbuj ponownie.</translation>
    </message>
    <message>
        <source>Failed to connect to backup services. Please check and retry again.</source>
        <translation>Nie udało się połączyć z usługami kopii zapasowej. Sprawdź problem i spróbuj ponownie.</translation>
    </message>
    <message>
        <source>Failed to connect to update services. Please check and retry again.</source>
        <translation>Nie udało się połączyć z usługami aktualizacji. Sprawdź problem i spróbuj ponownie.</translation>
    </message>
    <message>
        <source>Dependency error</source>
        <translation>Błąd zależności</translation>
    </message>
    <message>
        <source>DPKG error</source>
        <translation>Błąd DPKG</translation>
    </message>
    <message>
        <source>Back Up Again</source>
        <translation>Utwórz ponownie kopię zapasową</translation>
    </message>
    <message>
        <source>Abort</source>
        <translation>Przerwij</translation>
    </message>
    <message>
        <source>Proceed to Update</source>
        <translation>Przejdź do aktualizacji</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Uruchom ponownie</translation>
    </message>
    <message>
        <source>Shut Down</source>
        <translation>Zamknij</translation>
    </message>
    <message>
        <source>Go to Desktop</source>
        <translation>Przejdź na pulpit</translation>
    </message>
</context>
<context>
    <name>UpdatePrepareWidget</name>
    <message>
        <source>Preparing for updates…</source>
        <translation>Przygotowanie aktualizacji...</translation>
    </message>
</context>
<context>
    <name>UpdateProgressWidget</name>
    <message>
        <source>Do not force a shutdown or power off when installing updates. Otherwise, your system may be damaged.</source>
        <translation>Nie wymuszaj zamknięcia, ani nie odłączaj źródła zasilania podczas instalowania aktualizacji. W przeciwnym razie Twój system może ulec uszkodzeniu.</translation>
    </message>
    <message>
        <source>View update logs</source>
        <translation>Pokaż dziennik aktualizacji</translation>
    </message>
    <message>
        <source>Collapse update logs</source>
        <translation>Zwiń dziennik aktualizacji</translation>
    </message>
</context>
<context>
    <name>UpdateWorker</name>
    <message>
        <source>updatelog</source>
        <translation>Dziennik aktualizacji</translation>
    </message>
</context>
</TS>
